@@ -1,10 +1,10 @@
 package Net::DNS::Resolver::cygwin;
 
 #
-# $Id: cygwin.pm 1215 2014-06-05 16:01:16Z willem $
+# $Id: cygwin.pm 1233 2014-07-10 13:58:03Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1215 $)[1];
+$VERSION = (qw$LastChangedRevision: 1233 $)[1];
 
 =head1 NAME
 
@@ -19,7 +19,7 @@ use base qw(Net::DNS::Resolver::Base);
 
 sub getregkey {
 	my $key	  = $_[0] . $_[1];
-	my $value = '';
+	my $value;
 
 	local *LM;
 
@@ -29,7 +29,7 @@ sub getregkey {
 		close(LM);
 	}
 
-	return $value;
+	return $value || '';
 }
 
 
@@ -51,7 +51,7 @@ sub init {
 	# Best effort to find a useful domain name for the current host
 	# if domain ends up blank, we're probably (?) not connected anywhere
 	# a DNS server is interesting either...
-	my $domain = getregkey( $root, 'Domain' ) || getregkey( $root, 'DhcpDomain' ) || '';
+	my $domain = getregkey( $root, 'Domain' ) || getregkey( $root, 'DhcpDomain' );
 
 	# If nothing else, the searchlist should probably contain our own domain
 	# also see below for domain name devolution if so configured
@@ -59,8 +59,15 @@ sub init {
 	my $searchlist = "$domain ";
 	$searchlist .= getregkey( $root, 'SearchList' );
 
+
 	# This is (probably) adequate on NT4
-	my @nt4nameservers = split getregkey( $root, 'NameServer' ) || getregkey( $root, 'DhcpNameServer' );
+	my @nt4nameservers;
+	foreach ( grep length, getregkey( $root, 'NameServer' ), getregkey( $root, 'DhcpNameServer' ) ) {
+		push @nt4nameservers, split;
+		last;
+	}
+
+
 	my @nameservers;
 
 	#
@@ -72,15 +79,15 @@ sub init {
 	# drop any duplicates later
 	my $dnsadapters = $root . 'DNSRegisteredAdapters/';
 	if ( opendir( LM, $dnsadapters ) ) {
-		my @adapters = grep( $_ ne "." && $_ ne "..", readdir(LM) );
+		my @adapters = grep !/^\.\.?$/, readdir(LM);
 		closedir(LM);
 		foreach my $adapter (@adapters) {
 			my $regadapter = $dnsadapters . $adapter . '/';
 			if ( -e $regadapter ) {
-				my $ns = getregkey( $regadapter, 'DNSServerAddresses' ) || '';
-				while ( length($ns) >= 4 ) {
-					my $addr = join( '.', unpack( "C4", substr( $ns, 0, 4, "" ) ) );
-					push @nameservers, $addr;
+				my $ns = getregkey( $regadapter, 'DNSServerAddresses' );
+				until ( length($ns) < 4 ) {
+					push @nameservers, join '.', unpack( 'C4', $ns );
+					substr( $ns, 0, 4 ) = '';
 				}
 			}
 		}
@@ -88,22 +95,25 @@ sub init {
 
 	my $interfaces = $root . 'Interfaces/';
 	if ( opendir( LM, $interfaces ) ) {
-		my @ifacelist = grep( $_ ne '.' && $_ ne '..', readdir(LM) );
+		my @ifacelist = grep !/^\.\.?$/, readdir(LM);
 		closedir(LM);
 		foreach my $iface (@ifacelist) {
 			my $regiface = $interfaces . $iface . '/';
-			if ( opendir( LM, $regiface ) ) {
-				closedir(LM);
+			opendir( LM, $regiface ) || next;
+			closedir(LM);
 
-				my $ns;
-				my $ip;
-				$ip = getregkey( $regiface, 'DhcpIPAddress' ) || getregkey( $regiface, 'IPAddress' );
-				$ns = getregkey( $regiface, 'NameServer' )
-					|| getregkey( $regiface, 'DhcpNameServer' )
-					|| ''
-					unless !$ip || ( $ip =~ /0\.0\.0\.0/ );
+			my $ip = getregkey( $regiface, 'DhcpIPAddress' )
+					|| getregkey( $regiface, 'IPAddress' );
+			next unless $ip;
+			next if $ip eq '0.0.0.0';
 
-				push @nameservers, split $ns if $ns;
+			foreach (
+				grep length,
+				getregkey( $regiface, 'NameServer' ),
+				getregkey( $regiface, 'DhcpNameServer' )
+				) {
+				push @nameservers, split;
+				last;
 			}
 		}
 	}
@@ -111,7 +121,7 @@ sub init {
 	@nameservers = @nt4nameservers unless @nameservers;
 	$defaults->nameservers(@nameservers);
 
-	$defaults->{domain} = $domain if $domain;
+	$defaults->domain($domain) if $domain;
 
 	my $usedevolution = getregkey( $root, 'UseDomainNameDevolution' );
 	if ($searchlist) {
@@ -131,18 +141,10 @@ sub init {
 				}
 			}
 		}
-		$defaults->{searchlist} = [@a];
+		$defaults->searchlist(@a);
 	}
 
-
 	$class->read_env;
-
-
-	if ( !$defaults->{domain} && @{$defaults->{searchlist}} ) {
-		$defaults->{domain} = $defaults->{searchlist}[0];
-	} elsif ( !@{$defaults->{searchlist}} && $defaults->{domain} ) {
-		$defaults->{searchlist} = [$defaults->{domain}];
-	}
 }
 
 1;
